Development Lead
----------------

- Ian Cordasco <graffatcolmingov@gmail.com>

Requests
````````

- Kenneth Reitz <me@kennethreitz.com>

Design Advice
-------------

- Cory Benfield

Contributors
------------

- Marc Abramowitz (@msabramo)
- Bryce Boe <bbzbryce@gmail.com> (@bboe)
- Alex Richard-Hoyling <@arhoyling)
